<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><title>Home Assistant</title><link rel="manifest" href="/manifest.json"><link rel="icon" href="/static/icons/favicon.ico"><link rel="apple-touch-icon" sizes="180x180" href="/static/icons/favicon-apple-180x180.png"><link rel="mask-icon" href="/static/icons/mask-icon.svg" color="#3fbbf4"><link rel="preload" href="/frontend_latest/core-41bb07102212e1ea8b6668370a877b92.js" as="script"><link rel="preload" href="/static/fonts/roboto/Roboto-Regular.ttf" as="font" crossorigin=""><link rel="preload" href="/static/fonts/roboto/Roboto-Medium.ttf" as="font" crossorigin=""><meta name="apple-mobile-web-app-capable" content="yes"><meta name="msapplication-square70x70logo" content="/static/icons/tile-win-70x70.png"><meta name="msapplication-square150x150logo" content="/static/icons/tile-win-150x150.png"><meta name="msapplication-wide310x150logo" content="/static/icons/tile-win-310x150.png"><meta name="msapplication-square310x310logo" content="/static/icons/tile-win-310x310.png"><meta name="msapplication-TileColor" content="#3fbbf4ff"><meta name="mobile-web-app-capable" content="yes"><meta name="viewport" content="width=device-width,user-scalable=no"><meta name="theme-color" content="{{ theme_color }}"><style>body{font-family:'Roboto', 'Noto', sans-serif;font-weight:400;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;margin:0;padding:0;}#ha-init-skeleton::before{display:block;content:"";height:48px;background-color:{{ theme_color }};}#ha-init-skeleton .message{transition:font-size 2s;font-size:0;padding:24px;}#ha-init-skeleton.error .message{font-size:16px;}#ha-init-skeleton a{color:{{ theme_color }};text-decoration:none;font-weight:bold;}</style><script>function initError(){document.getElementById("ha-init-skeleton").classList.add("error")}window.noAuth="{{ no_auth }}",window.Polymer={lazyRegister:!0,useNativeCSSProperties:!0,dom:"shadow",suppressTemplateNotifications:!0,suppressBindingNotifications:!0};</script></head><body><div id="ha-init-skeleton"><div class="message">Home Assistant had trouble<br>connecting to the server.<br><br><a href="/">TRY AGAIN</a></div></div><home-assistant></home-assistant><script>var webComponentsSupported="customElements"in window&&"import"in document.createElement("link")&&"content"in document.createElement("template");if(!webComponentsSupported){var e=document.createElement("script");e.onerror=initError,e.src="/static/webcomponents-lite.js","import"in document.createElement("link")?document.write(e.outerHTML):document.head.appendChild(e)}"serviceWorker"in navigator&&window.addEventListener("load",function(){navigator.serviceWorker.register("/service_worker.js")});</script><script src="/frontend_latest/core-41bb07102212e1ea8b6668370a877b92.js"></script><link rel="import" href="/frontend_latest/frontend-2216be04a5c7ff162a7ea60688a711e8.html" onerror="initError()">{% if panel_url -%}<link rel="import" href="{{ panel_url }}" async="">{% endif -%}<link rel="import" href="/static/mdi-f2044fa708a68df282813586003b987b.html" async="">{% for extra_url in extra_urls -%}<link rel="import" href="{{ extra_url }}" async="">{% endfor -%}</body></html>