!function(){"use strict";function e(e,t){if(void 0===e||null===e)throw new TypeError("Cannot convert first argument to object");for(var r=Object(e),n=1;n<arguments.length;n++){var o=arguments[n];if(void 0!==o&&null!==o)for(var s=Object.keys(Object(o)),u=0,i=s.length;u<i;u++){var a=s[u],c=Object.getOwnPropertyDescriptor(o,a);void 0!==c&&c.enumerable&&(r[a]=o[a])}}return r}Array.prototype.includes||(Array.prototype.includes=function(e){if(null==this)throw new TypeError("Array.prototype.includes called on null or undefined");var t=Object(this),r=parseInt(t.length,10)||0;if(0===r)return!1;var n,o=parseInt(arguments[1],10)||0;o>=0?n=o:(n=r+o)<0&&(n=0);for(var s;n<r;){if(s=t[n],e===s||e!=e&&s!=s)return!0;n++}return!1});var t="function"==typeof fetch?fetch.bind():function(e,t){return t=t||{},new Promise(function(r,n){function o(){var e,t=[],r=[],n={};return s.getAllResponseHeaders().replace(/^(.*?):\s*([\s\S]*?)$/gm,function(o,s,u){t.push(s=s.toLowerCase()),r.push([s,u]),e=n[s],n[s]=e?e+","+u:u}),{ok:1==(s.status/200|0),status:s.status,statusText:s.statusText,url:s.responseURL,clone:o,text:function(){return Promise.resolve(s.responseText)},json:function(){return Promise.resolve(s.responseText).then(JSON.parse)},blob:function(){return Promise.resolve(new Blob([s.response]))},headers:{keys:function(){return t},entries:function(){return r},get:function(e){return n[e.toLowerCase()]},has:function(e){return e.toLowerCase()in n}}}}var s=new XMLHttpRequest;s.open(t.method||"get",e);for(var u in t.headers)s.setRequestHeader(u,t.headers[u]);s.withCredentials="include"==t.credentials,s.onload=function(){r(o())},s.onerror=n,s.send(t.body)})},r=Object.freeze({default:t}),n=r&&t||r;window.fetch||(window.fetch=n.default||n);({assign:e,polyfill:function(){Object.assign||Object.defineProperty(Object,"assign",{enumerable:!1,configurable:!0,writable:!0,value:e})}}).polyfill()}();